# install Towles Tool globally


To install Python executables into your PATH, provide the `--preview` option:

https://docs.astral.sh/uv/concepts/python-versions/#installing-python-executables


```bash
uv python install 3.13 --default --preview

which python


```
